.. _async_transports:

Async Transports
================

Async transports are transports which are using an underlying async library. They allow us to
:ref:`run GraphQL queries asynchronously <async_usage>`

.. toctree::
   :maxdepth: 1

   aiohttp
   httpx_async
   websockets
   aiohttp_websockets
   phoenix
   appsync
